# Changelog

All notable changes to the Chroma MCP Server will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.1.0] - 2025-03-29

### Added

- Initial release of Chroma MCP Server
- Collection management tools
- Document operation tools
- Sequential thinking tools
- Comprehensive test suite
- Documentation
